==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ToolPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.aa("ToolPanelContentRefreshedEventArgs", () => new ToolPanelContentRefreshedEventArgsDescription());
            a.z("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolPanelContentRefreshedEventArgsDescription } from "./ToolPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
export let ToolPanelContentRefreshedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolPanelContentRefreshedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolPanelContentRefreshedEventArgsDescriptionMetadata.c(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ToolPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
            a.ac("ToolPanelContentRefreshedEventArgs", () => new ToolPanelContentRefreshedEventArgsDescription());
            a.ab("ToolPanelContentRefreshedEventArgs", ToolPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
    }
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolPanelContentRefreshedEventArgsDescriptionMetadata, 'ToolPanelContentRefreshedEventArgsDescriptionMetadata');
    ToolPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ToolPanelContentRefreshedEventArgsDescriptionMetadata;
})();
